@@ -97,18 +97,46 @@ shape_for_route <- function(g1, select_route_id, select_service_id) {
 #' 
 #' @param a dataframe output by join_mega_and_hf_routes()
 #' @param route_ids the ids of the routes
-#' @param service_id the service for which to get stops 
+#' @param service_ids the service for which to get stops 
 #' @param directional if the routes should by related to a route direction (e.g. inbound, outbound) - currently not implemented
 #' @return shapes for routes
 #' @keywords internal
-shapes_for_routes <- function(g1, route_ids, select_service_ids, directional=FALSE) {
+shapes_for_routes <- function(g1, route_ids, service_ids, directional=FALSE) {
   l1 = list()
   i <- 1
   for (route_id in route_ids) {
-    l1[[i]] <- shape_for_route(g1,route_id, select_service_ids)
+    l1[[i]] <- shape_for_route(g1,route_id, service_ids)
     i <- i + 1
   }
   df_routes <- do.call("rbind", l1)
   return(df_routes)
 }
 
+
+#' Get a set of stops for a given set of service ids and route ids
+#' 
+#' @param gtfs_obj as read by read_gtfs()
+#' @param service_ids the service for which to get stops 
+#' @param route_ids the route_ids for which to get stops 
+#' @return stops for a given service
+#' @export
+#' @examples \donttest{
+#' local_gtfs_path <- system.file("extdata", "google_transit_nyc_subway.zip", package = "tidytransit")
+#' nyc <- read_gtfs(local_gtfs_path,local=TRUE)
+#' select_service_id <- filter(nyc$calendar_df,monday==1) %>% pull(service_id)
+#' select_route_id <- sample_n(nyc$routes_df,1) %>% pull(route_id)
+#' filtered_stops_df <- filter_stops(nyc,select_service_id,select_route_id)
+#' }
+filter_stops <- function(gtfs_obj, service_ids, route_ids) {
+  some_trips <- gtfs_obj$trips_df %>%
+    dplyr::filter(.data$service_id %in% service_ids &
+                    .data$route_id %in% route_ids)
+  
+  some_stop_times <- gtfs_obj$stop_times_df %>% 
+    dplyr::filter(.data$trip_id %in% some_trips$trip_id) 
+  
+  some_stops <- gtfs_obj$stops_df %>%
+    dplyr::filter(.data$stop_id %in% some_stop_times$stop_id)
+  
+  return(some_stops)
+}
\ No newline at end of file
