@@ -33,36 +33,6 @@ test_that('Downloading a zip file from a gtfs_example_url returns a file', {
   }
 })
 
-test_that('Unzip and list GTFS files returns more than 4 files', {
-  skip_on_cran()
-  if(working()==FALSE){
-    skip("no internet, skipping")
-  }
-  else {
-  
-  zip <- tidytransit:::download_from_url(gtfs_example_url)
-  folder <- tidytransit:::unzip_file(zip)
-  files <- tidytransit:::list_files(folder)
-
-  expect_true(length(files)>4)
-  }
-})
-
-test_that('Read and validate returns a list of class "gtfs"', {
-  skip_on_cran()
-  if(working()==FALSE){
-    skip("no internet, skipping")
-  }
-  else {
-  
-  zip <- tidytransit:::download_from_url(gtfs_example_url)
-  folder <- tidytransit:::unzip_file(zip)
-  files <- tidytransit:::list_files(folder)
-
-  expect_is(read_and_validate(files), 'gtfs')
-  }
-})
-
 test_that('import-bad paths throw good errors', {
   skip_on_cran()
   not_a_url <- "#!:D"
@@ -86,8 +56,8 @@ test_that('import-empty txt files are not imported and non-empty ones are import
     files <- list.files(folder, full.names = TRUE)
     empty_file <- files[1]
     
-    expect_null(tidytransit:::parse_gtfs('_empty', empty_file)) # expect null since file is empty
-    expect_is(tidytransit:::parse_gtfs('agency', agency_file), 'tbl_df') # check for tibble object
+    expect_null(tidytransit:::parse_gtfs_file('_empty', empty_file)) # expect null since file is empty
+    expect_is(tidytransit:::parse_gtfs_file('agency', agency_file), 'tbl_df') # check for tibble object
   }
 })
 
@@ -126,15 +96,9 @@ test_that('Some minimal validation is performed and returned', {
   skip_on_cran()
   if(working()){
     gtfs_obj1 <- tidytransit::read_gtfs(gtfs_example_url)
-    expect_true(gtfs_obj1$validation$all_req_files)
     
-    expect_true(dim(gtfs_obj1$validation$full_column_and_file_validation_df)[1]>0)
-    expect_true(dim(gtfs_obj1$validation$full_column_and_file_validation_df)[2]==10)
-    
-    x <- c("all_req_files", "all_req_fields_in_req_files", "all_req_fields_in_opt_files",
-           "full_column_and_file_validation_df")
-    
-    expect_true(table(x %in% names(gtfs_obj1$validation))[['TRUE']]==4) # check that it has required names
+    expect_true(dim(attributes(gtfs_obj1)$validation_result)[1]>0)
+    expect_true(dim(attributes(gtfs_obj1)$validation_result)[2]>0)
   }
 })
 
